﻿using System;
using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "InfoBar 엘리먼트 : Message/ActionButton 속성 사용하기";

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 메시지 콤보 박스 선택 변경시 처리하기 - messageComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// 메시지 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void messageComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.infoBar == null)
            {
                return;
            }

            if(this.messageComboBox.SelectedIndex == 0)
            {
                this.infoBar.Message = "A short essential app message.";
            }
            else if(this.messageComboBox.SelectedIndex == 1)
            {
                this.infoBar.Message = "A long essential app message for your users to be informed of, acknowledge, or take action on. " +
                                       "Lorem ipsum dolor sit amet, consectetur adipiscing elit. "                                       +
                                       "Proin dapibus dolor vitae justo rutrum, ut lobortis nibh mattis. "                               +
                                       "Aenean id elit commodo, semper felis nec.";
            }
        }

        #endregion
        #region 액션 버튼 콤보 박스 선택 변경시 처리하기 - actionButtonComboBox_SelectionChanged(sender, e)

        /// <summary>
        /// 액션 버튼 콤보 박스 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void actionButtonComboBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(this.infoBar == null)
            {
                return;
            }

            if(this.actionButtonComboBox.SelectedIndex == 0)
            {
                this.infoBar.ActionButton = null;
            }
            else if(this.actionButtonComboBox.SelectedIndex == 1)
            {
                Button button = new Button();

                button.Content = "액션";

                this.infoBar.ActionButton = button;
            }
            else if(this.actionButtonComboBox.SelectedIndex == 2)
            {
                HyperlinkButton hyperlinkButton = new HyperlinkButton();

                hyperlinkButton.NavigateUri = new Uri("http://www.microsoft.com/");
                hyperlinkButton.Content     = "정보 링크";

                this.infoBar.ActionButton = hyperlinkButton;
            }
        }

        #endregion
    }
}